Module value

Module value 

Value-tree operations over the canonical serde_json::Value model.

Enums

ArrayStrategy
How to combine two arrays found at the same key during a merge.

Functions

merge
Deep-merge overlay onto base, replacing arrays wholesale.
merge_with
Deep-merge overlay onto base, choosing an array strategy per key.