#[non_exhaustive]pub enum ArrayStrategy {
Replace,
Concat,
}Expand description
How to combine two arrays found at the same key during a merge.
The strategy is chosen per key by the caller (see merge_with); the merge
mechanism itself is policy-free — it does not know what any key “means”.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Replace
The overlay array replaces the base array wholesale (last-wins).
Concat
The overlay array is appended to the base array (concatenation).